﻿' --------------------------------------------------------------
' Creates a simple pulse by setting a digital I/O line to high,
' a Sleep delay and setting the line to low. The Sleep delay
' is timed.
'
' support@labjack.com
' --------------------------------------------------------------

' Import the UD .NET wrapper object.  The dll ByReferenced is installed by the
' LabJackUD installer.
Imports LabJack.LabJackUD
Imports System.Diagnostics

Public Class U6_DigitalOutPulse

    Private Sub addMessages(ByVal text As String)
        messagesTB.AppendText(text & Environment.NewLine)
    End Sub

    Private Sub clearMessages()
        messagesTB.Clear()
    End Sub

    Private Sub runButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles runButton.Click
        Dim u6 As U6
        Dim dioNum As Integer
        Dim pulseTime As Integer 'In ms
        Dim stopWatch As New Stopwatch()

        clearMessages()

        Try
            dioNum = dioNUD.Value
            pulseTime = timeNUD.Value

            'Open first found U6
            u6 = New U6(LJUD.CONNECTION.USB, "0", True)

            'Doing the pulse

            'Output high
            LJUD.ePut(u6.ljhandle, LJUD.IO.PUT_DIGITAL_BIT, dioNum, 1, 0)

            'Delay
            stopWatch.Start()
            Threading.Thread.Sleep(pulseTime)
            stopWatch.Stop()

            'Output low
            LJUD.ePut(u6.ljhandle, LJUD.IO.PUT_DIGITAL_BIT, dioNum, 0, 0)

            addMessages("Sleep time: " & Str(stopWatch.Elapsed.TotalMilliseconds) & " ms")

        Catch ljex As LabJackUDException
            addMessages("LabJackUD Error #" & Str$(ljex.LJUDError) & "  " & ljex.ToString())
        Catch ex As Exception
            addMessages("Exception: " & ex.Message)
        End Try

        addMessages("Done")
    End Sub
End Class
